MIT_PREAMBLE = "permission is hereby granted, free of charge, to any person obtaining a copy of"
BSD_PREAMBLE = "redistribution and use in source and binary forms, with or without modification"
BSD_CLAUSE_1 = "redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer."
BSD_CLAUSE_2 = "redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution."
BSD_CLAUSE_3 = "all advertising materials mentioning features or use of this software must display the following acknowledgement:"
BSD_CLAUSE_4 = "be used to endorse or promote products derived from this software without"


LICENSE_TREE = (
    (MIT_PREAMBLE, (
        ("x11 license", "X11"),
        ("icu license - icu 1.8.1 and later", "ICU"),
        ("imlib2 license", "Imlib2"),
        ("university of illinois/ncsa open source license", "NCSA"),
        ("(version 2.0, sept. 18, 2008)", "SGI-B-2.0"),
        ("xfree86 license (version 1.1)", "XFree86-1.1"),
        ("the x.net, inc. license", "Xnet"),
        ("the above copyright notice and this permission notice shall be included in all copies of the software and its documentation and acknowledgment shall be given in the documentation and software packages that this software was used.", "MIT-feh"),
        (
            "the above copyright notice and this permission notice shall be", (
                ("its documentation and marketing & publicity materials", "MIT-advertising"),
                ("this agreement shall be governed in all respects by the laws of the state of california and by the laws of the united states of america.", "Xnet"),
                ("distributions of all or part of the software intended to be used by the recipients", "MITNFA"),
                ("in addition publicly documented acknowledgment must", (
                    ("making the source available publicly means including the source for this software with the distribution", "Imlib2"),
                    ("", "MIT-enna"))),
                ("the software shall be used for good, not evil.", "JSON"),
                ("without warranty of any kind", "MIT"))),
        ("the above copyright notice and this permission notice shall be included in all copies of the software", "MIT-advertising"))),
    ("the tmate open source license.", "TMate"),
    ("the sleepycat license copyright", "Sleepycat"),
    ("nrl license", "NRL"),
    ("the php license,", (
        ("version 3.01", "PHP-3.01"),
        ("version 3.0", "PHP-3.0"))),
    ("sendmail license", "Sendmail"),
    ("bsd-4-clause (university of california-specific)", "BSD-4-Clause-UC"),
    ("permission to use, copy, modify", (
        ("and/or distribute this software for any purpose with or without fee is hereby granted.", "0BSD"),
        ("the educational community license", "ECL-1.0"),
        ("historical permission notice and disclaimer", "HPND"),
        ("and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.", "ISC"),
        ("derivative work - 1996, 1998-2000 copyright 1996, 1998-2000 the regents of the university of california", "MIT-CMU"),
        ("multics license", "Multics"),
        ("ntp license (ntp)", "NTP"),
        ("the open source pil software license:", "PIL"),
        ("postgresql database management system", "PostgreSQL"),
        ("python software foundation license version 2", "Python-2.0"),
        ("realnetworks public source license version 1.0", "RPSL-1.0"),
        ("standard ml of new jersey copyright notice, license and disclaimer.", "SMLNJ"),
        ("the authors hereby grant permission to use", (
            ("by installing this software, you acknowledge that you have read this agreement", "SWL"),
            ("the authors and distributors specifically disclaim any warranties", "TCL"))),
        ("w3c(r) software notice and license", "W3C-19980720"),
        ("and distribute this software for any purpose", "curl"),
        ("distribute, and sell this software and its documentation for any purpose is hereby granted without fee, provided that", "libtiff"),
    )),
    ("intel open source license", "Intel"),
    ("openssl license", "OpenSSL"),
    (BSD_PREAMBLE, (
        (BSD_CLAUSE_1, (
            (BSD_CLAUSE_2, (
                (BSD_CLAUSE_4, (
                    (BSD_CLAUSE_3, "BSD-4-Clause"),
                    ("no express or implied licenses to any party's patent rights are granted by this license.", "BSD-3-Clause-Clear"),
                    ("must not be used to endorse or promote products derived from this software without prior written permission.", (
                        ("products derived from this software may not be called", (
                            ("redistributions of any form whatsoever must retain the following acknowledgment", "Apache-1.0"),
                            ("the end-user documentation included with the redistribution, if any, must include the following acknowledgment", "Apache-1.1"),
                            ("", "VSL-1.0"))),)),
                    ("may publish revised and/or new versions of the license from time to time.", "Zend-2.0"),
                    ("you are under no obligation whatsoever to provide any bug fixes", "BSD-3-Clause-LBNL"),
                    ("you acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.", "BSD-3-Clause-No-Nuclear-License-2014"),
                    ("redistributions of any form whatsoever must retain the following acknowledgment: 'this product includes software developed by the", "BSD-3-Clause-Attribution"),
                    ("", "BSD-3-Clause")
                )),
                ("any additions, deletions, or changes to the original files must be clearly indicated", "Mup"),
                ("redistributions in any form must be accompanied by information on how to obtain complete", "TOSL"),
                ("this software is provided by", (
                    ("this code is derived from software contributed to the netbsd foundation", "BSD-2-Clause-NetBSD"),
                    ("the views and conclusions contained in the software and documentation are those of the authors and should not be interpreted as representing official policies, either expressed or implied, of the freebsd project.", "BSD-2-Clause-FreeBSD"),
                    ("", "BSD-2-Clause"),)),
                ("all advertising materials mentioning features or use of this software must display the following acknowledgement:", "BSD-4-Clause"))),
            ("the origin of this software must not be misrepresented; you must not claim that you wrote the original software. if you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.", (
                ("version 1.0.5 of 10 december 2007", "bzip2-1.0.5"),
                ("", "bzip2-1.0.6"),)))),
        ("software license for mtl", "MTLL"),
        ("redistributions in source code must retain the above copyright notice", (
            ("zope public license (zpl) version 2.0", "ZPL-2.0"),
            ("all advertising materials and documentation mentioning features derived from or use of this software must display the following acknowledgement", "ZPL-1.1"),
            ("", "Naumen"))),
        ("redistribution of source code must retain the above copyright", (
            ("you acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.", "BSD-3-Clause-No-Nuclear"),
            ("you acknowledge that this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.", "BSD-3-Clause-No-Nuclear"))))),
    ("the openldap public license", (
        ("version 2.7, 7 september 2001", "OLDAP-2.7"),
        ("version 2.2, 1 march 2000", "OLDAP-2.2"),
        ("version 2.3, 28 july 2000", "OLDAP-2.3"),
        ("version 2.2.2, 28 july 2000", "OLDAP-2.2.2"),
        ("version 2.8, 17 august 2003", "OLDAP-2.8"),
        ("version 2.2.1, 1 march 2000", "OLDAP-2.2.1"),
        ("version 2.6, 14 june 2001", "OLDAP-2.6"),
        ("version 2.5, 11 may 2001", "OLDAP-2.5"),
        ("version 2.0, 7 june 1999", "OLDAP-2.0"),
        ("version 2.4, 8 december 2000", "OLDAP-2.4"),
        ("version 2.1, 29 february 2000", "OLDAP-2.1"),
        ("version 2.0.1, 21 december 1999", "OLDAP-2.0.1"))),
    ("licence libre du quebec", (
        ("reciprocite forte (liliq-r+)", "LiLiQ-Rplus-1.1"),
        ("permissive (liliq-p)", "LiLiQ-P-1.1"),
        ("reciprocite (liliq-r)", "LiLiQ-R-1.1"))),
    ("cecill", (
        ("contrat de licence de logiciel libre cecill-c", "CECILL-C"),
        ("contrat de licence de logiciel libre cecill-b", "CECILL-B"),
        ("2.1 du 2013-06-21", "CECILL-2.1"),
        ("2.0 du 2006-09-05.", "CECILL-2.0"),
        ("2.1 dated 2013-06-21", "CECILL-2.1"),
        ("1 du 21/06/2004", "CECILL-1.0"),
        ("free software licensing agreement cecill", "CECILL-1.1"))),
    ("redistribution and use of this software in source and binary forms, with or without modification, are permitted provided that the following conditions are met:", "BSD-Source-Code"),
    ("3dfx glide source code general public license", "Glide"),
    ("nasa open source agreement version 1.3", "NASA-1.3"),
    ("common development and distribution license (cddl)", (
        ("version 1.0", "CDDL-1.0"),
        ("version 1.1", "CDDL-1.1"))),
    ("the national science and technology research center for computation and visualization of geometric structures (the geometry center) university of minnesota", "Qhull"),
    ("portions of this material resulted from work developed under a u.s. government contract", "mpich2"),
    ("odc open database license (odbl)", "ODbL-1.0"),
    ("nokia open source license (nokos license)", "Nokia"),
    ("open public license", (
        ("version 1.0", "OPL-1.0"),)),
    ("licence art libre", (
        ("version 1.2", "LAL-1.2"),
        ("1.3 (lal 1.3)", "LAL-1.3"))),
    ("academic free license (\"afl\") v. 3.0", "AFL-3.0"),
    ("do what the fuck you want to public license", (
        ("version 2, december 2004", "WTFPL"),)),
    ("academic free license", (
        ("version 1.1", "AFL-1.1"),
        ("version 1.2", "AFL-1.2"))),
    ("permission is granted to make and distribute verbatim copies of this manual provided the copyright notice and this permission notice are preserved on all copies.", "Latex2e"),
    ("this software is distributed in the hope that it will be useful, but with no warranty of any kind.", "Leptonica"),
    ("copying and distribution of this file, with or without modification, are permitted in any medium without royalty provided the", "FSFAP"),
    ("sgi free software license b", (
        ("(version 1.0 1/25/2000)", "SGI-B-1.0"),
        ("(version 1.1 02/22/2000)", "SGI-B-1.1"))),
    ("insert gpl v3 text here", (
        ("gcc runtime library exception", "deprecated_GPL-3.0-with-GCC-exception"),
        ("autoconf configure script exception", "deprecated_GPL-3.0-with-autoconf-exception"))),
    ("this file may be freely transmitted and reproduced, but it may not be changed unless the name is changed also", "Dotseqn"),
    ("oset public license", "OSET-PL-2.1"),
    ("fair license", "Fair"),
    ("ipa font license agreement v1.0", "IPA"),
    ("code derived from the document", (
        ("haskell 2010", "HaskellReport"),)),
    ("\"the beer-ware license\" (revision 42): <phk@freebsd.org> wrote this file.", "Beerware"),
    ("miros license", "MirOS"),
    ("each contributor hereby grants to you a perpetual, worldwide", (
        ("educational community license", (
            ("version 2.0, april 2007", "ECL-2.0"),)),
        ("to apply the imagemagick license to your work", "ImageMagick"),
        ("you may add your own copyright statement to your modifications", "Apache-2.0")
    )),
    ("insert gpl v2 text here", (
        ("font exception", "deprecated_GPL-2.0-with-font-exception"),
        ("gcc linking exception", "deprecated_GPL-2.0-with-GCC-exception"))),
    ("this copy of the libpng notices is provided for your convenience.", "Libpng"),
    ("acpi - software license agreement", "Intel-ACPI"),
    ("the academic free license", (
        ("v. 2.0", "AFL-2.0"),
        ("v.2.1", "AFL-2.1"))),
    ("you may freely use, modify, and/or distribute each of the files in this package without limitation. the package consists of the following files:", "Borceux"),
    ("the artistic license 2.0", "Artistic-2.0"),
    ("a world-wide, royalty-free, non-exclusive right to distribute, copy, modify, create derivatives, and use, in source and binary forms, is hereby granted", "AMPAS"),
    ("permission to use, copy, and distribute this software", (
        ("gl2ps license version 2, november 2003", "GL2PS"),
        ("original license: this software is", "xinetd"),
        ("permission to modify the software is granted", "gnuplot"))),
    ("sugarcrm public license", "SugarCRM-1.1.3"),
    ("the initial developer hereby grants you a world-wide, royalty-free, non-exclusive license, subject to third party intellectual property claims:", (
        ("common public attribution license version 1.0", "CPAL-1.0"),
        ("cua office public license version 1.0", "CUA-OPL-1.0"),
        ("erlang public license version 1.1", "ErlPL-1.1"),
        ("freeimage public license - version 1.0", "FreeImage"),
        ("interbase public license", (
            ("version 1.0", "Interbase-1.0"),)),
        ("netscape public license version 1.1", "NPL-1.1"),
        ("netscape public license version 1.0", "NPL-1.0"),
        ("red hat ecos public license v1.1", "RHeCos-1.1"),
        ("sun industry standards source license", (
            ("version 1.2", "SISSL-1.2"),)),
        ("sun industry standards source license - version 1.1", "SISSL"),
        ("storage networking industry association", (
            ("version 1.1", "SNIA"),)),
        ("sun public license version 1.0", "SPL-1.0"),
        ("gsoap public license", "gSOAP-1.3b"),
    )),
    ("mozilla public license", (
        ("version 2.0", "MPL-2.0"),
        ("version 1.0", "MPL-1.0"),
        ("version 1.1", "MPL-1.1"))),
    ("no limit public license", "NLPL"),
    ("this file was added by clea f. rees on 2008/11/30 with the permission of dean guenther and pointers to this file were added to all source files.", "Wsuipa"),
    ("permission is granted to anyone to use this software for any purpose on any computer system, and to redistribute it freely, subject to the following restrictions:", (
        ("the author is not responsible for the consequences of use of this software, no matter how awful, even if they arise from defects in it.", "Spencer-86"),
        ("this software is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose.", "Newsletr"))),
    ("european union public licence", (
        ("v.1.0", "EUPL-1.0"),
        ("v. 1.1", "EUPL-1.1"))),
    ("this source code has been made available to you by ibm on an as-is basis.", "IBM-pibs"),
    ("cnri open source gpl-compatible license agreement", "CNRI-Python-GPL-Compatible"),
    ("scea shared source license 1.0", "SCEA"),
    ("torque v2.5+ software license v1.1", "TORQUE-1.1"),
    ("license for the extreme! lab pullparser", "xpp"),
    ("caldera international, inc. hereby grants a fee free license", "Caldera"),
    ("this file is free software; the free software foundation gives unlimited permission to copy and/or distribute it, with or without modifications, as long as this notice is preserved.", "FSFULLR"),
    ("cnri open source license agreement", "CNRI-Python"),
    ("ricoh source code public license", (
        ("version 1.0", "RSCPL"),)),
    ("these patterns were developed for internal gmv use and are made public", "Bahyph"),
    ("development of this software was funded, in part, by cray research inc., uunet communications services inc., sun microsystems inc., and scriptics corporation, none of whom are responsible for the results. the author thanks all of them.", "Spencer-99"),
    ("insert gpl v2 license text here", (
        ("class path exception", "deprecated_GPL-2.0-with-classpath-exception"),
        ("autoconf exception", "deprecated_GPL-2.0-with-autoconf-exception"))),
    ("sax is free!", "SAX-PD"),
    ("deutsche freie software lizenz", "D-FSL-1.0"),
    ("the freetype project license", "FTL"),
    ("this material was originally written and compiled by wietse venema at eindhoven university of technology, the netherlands, in 1990, 1991, 1992, 1993, 1994 and 1995.", "TCP-wrappers"),
    ("independent jpeg group license", "IJG"),
    ("creative commons", (
        ("attribution 4.0 international", "CC-BY-4.0"),
        ("attribution-sharealike 4.0 international", "CC-BY-SA-4.0"),
        ("attribution 3.0 unported", "CC-BY-3.0"),
        ("attribution 1.0", "CC-BY-1.0"),
        ("attribution-noderivatives 4.0 international", "CC-BY-ND-4.0"),
        ("attribution 2.5", "CC-BY-2.5"),
        ("attribution-noncommercial-sharealike 2.0", "CC-BY-NC-SA-2.0"),
        ("attribution-noderivs 2.5", "CC-BY-ND-2.5"),
        ("attribution-noncommercial-noderivs 2.0", "CC-BY-NC-ND-2.0"),
        ("attribution-noderivs 1.0", "CC-BY-ND-1.0"),
        ("attribution-noncommercial 3.0 unported", "CC-BY-NC-3.0"),
        ("attribution-noncommercial-noderivatives 4.0 international", "CC-BY-NC-ND-4.0"),
        ("attribution-noderivs 2.0", "CC-BY-ND-2.0"),
        ("attribution-noncommercial 2.5", "CC-BY-NC-2.5"),
        ("attribution-noncommercial-noderivs 2.5", "CC-BY-NC-ND-2.5"),
        ("attribution-noderivs 3.0 unported", "CC-BY-ND-3.0"),
        ("attribution-noncommercial-sharealike 2.5", "CC-BY-NC-SA-2.5"),
        ("attribution-noncommercial 2.0", "CC-BY-NC-2.0"),
        ("cc0 1.0 universal", "CC0-1.0"),
        ("attribution-sharealike 2.5", "CC-BY-SA-2.5"),
        ("attribution-sharealike 1.0", "CC-BY-SA-1.0"),
        ("attribution-sharealike 2.0", "CC-BY-SA-2.0"),
        ("attribution-noncommercial-sharealike 4.0 international", "CC-BY-NC-SA-4.0"),
        ("attribution-noncommercial-sharealike 3.0 unported", "CC-BY-NC-SA-3.0"),
        ("attribution-noncommercial-sharealike 1.0", "CC-BY-NC-SA-1.0"),
        ("attribution-noderivs-noncommercial 1.0", "CC-BY-NC-ND-1.0"),
        ("attribution-noncommercial 1.0", "CC-BY-NC-1.0"),
        ("attribution-noncommercial 4.0 international", "CC-BY-NC-4.0"),
        ("attribution-sharealike 3.0 unported", "CC-BY-SA-3.0"),
        ("attribution-noncommercial-noderivs 3.0 unported", "CC-BY-NC-ND-3.0"),
        ("attribution 2.0", "CC-BY-2.0"))),
    ("zlib license", "Zlib"),
    ("psfrag.dtx", "psfrag"),
    ("this file and the 14 postscript(r) afm files it accompanies", "APAFML"),
    ("affero general public license", (
        ("version 1, march 2002 copyright (c) 2002 affero inc. 510 third street - suite 225, san francisco, ca 94107, usa", "AGPL-1.0"),)),
    ("this program discloses material protectable under copyright laws of the united states.", "DSDP"),
    ("redistribution and use of this software and associated documentation (\"software\"), with or without modification, are permitted provided that the following conditions are met:", "Plexus"),
    ("egenix.com public license agreement", (
        ("version 1.1.0", "eGenix"),)),
    ("use and copying of this software and preparation of derivative works based upon this", "Xerox"),
    ("unicode terms of use", "Unicode-TOU"),
    ("you get the royalty free right to:", "SimPL-2.0"),
    ("non-profit open software license 3.0", "NPOSL-3.0"),
    ("this configure script is free software; the free software foundation gives unlimited permission to copy, distribute and modify it.", "FSFUL"),
    ("noweb is copyright 1989-2000 by norman ramsey. all rights reserved.", "Noweb"),
    ("adobe systems incorporated(r) source code license agreement", "Adobe-2006"),
    ("the source code in this package is copyright 1999-2010 by andrew plotkin.", "Glulxe"),
    ("rdisc (this program) was developed by sun microsystems, inc. and is provided for unrestricted use provided that this legend is included on all tape media and as a part of the software program in whole or part. users may copy or modify rdisc without charge, and they may freely distribute it.", "Rdisc"),
    ("antlr 2 license", "ANTLR-PD"),
    ("this is apreambl.tex, version 1.10e, written by hans-hermann bode", "Abstyles"),
    ("open software license v. 3.0 (osl-3.0)", "OSL-3.0"),
    ("you can do what you want with it", "diffmark"),
    ("attribution assurance license", "AAL"),
    ("the frameworx open license 1.0", "Frameworx-1.0"),
    ("crystal stacker is freeware. this means you can pass copies around freely provided you include this document in it's original form in your distribution. please see the \"contacting us\" section of this document if you need to contact us for any reason.", "CrystalStacker"),
    ("nethack general public license", "NGPL"),
    ("gnu lesser general public license version 2.1, february 1999", "LGPL-2.1"),
    ("this version of the gnu lesser general public license", "LGPL-3.0"),
    ("each contributor grants you a non-exclusive", (
        ("version 3, 19 november 2007", "AGPL-3.0"),
        ("this program is free software: you can redistribute it and/or modify", (
            ("either version 3", "GPL-3.0"),)),
        ("microsoft reciprocal license (ms-rl)", "MS-RL"),
        ("microsoft public license (ms-pl)", "MS-PL"),
    )),
    ("ibm public license version 1.0", "IPL-1.0"),
    ("open software licensev. 2.0", "OSL-2.0"),
    ("this fastcgi application library source and object code (the \"software\")", "OML"),
    ("zope public license (zpl) version 2.1", "ZPL-2.1"),
    ("permission is hereby granted, free of charge, to any person obtaining a copy of this documentation file to use, copy, publish, distribute, sublicense, and/or sell copies of the documentation, and to permit others to do the same, provided that:", "Adobe-Glyph"),
    ("vostrom public license for open source", "VOSTROM"),
    ("the code project open license (cpol) 1.02", "CPOL-1.02"),
    ("ps utilities package", "psutils"),
    ("w3c software notice and license", "W3C"),
    ("adaptive public license", (
        ("version 1.0", "APL-1.0"),)),
    ("open data commons - public domain dedication & license (pddl)", "PDDL-1.0"),
    ("bison exception", "deprecated_GPL-2.0-with-bison-exception"),
    ("this is a package of commutative diagram macros built on top of xy-pic", "Barr"),
    ("you can use doc software in commercial and/or binary software releases and are under no obligation to redistribute any", "DOC"),
    ("the q public license version 1.0", "QPL-1.0"),
    ("the sfl license agreement", "iMatix"),
    ("licensed under the apache license, version 2.0", "Apache-2.0"),
    ("secure messaging protocol (smp) libraries", "SMPPL"),
    ("lesser general public license for linguistic resources", "LGPLLR"),
    ("a modified version of this file may be distributed, but it should be distributed with a *different* name. changed files must be distributed *together with a complete and unchanged* distribution of these files.", "dvipdfm"),
    ("license to copy and use this software is granted provided that it is identified as the \"rsa data security, inc.", "RSA-MD"),
    ("the latex project public license", (
        ("lppl version 1.0 1999-03-01", "LPPL-1.0"),
        ("lppl version 1.3a 2004-10-01", "LPPL-1.3a"),
        ("lppl version 1.1 1999-07-10", "LPPL-1.1"),
        ("lppl version 1.3c 2008-05-04", "LPPL-1.3c"),
        ("lppl version 1.2 1999-09-03", "LPPL-1.2"))),
    ("this code is derived from software contributed to the netbsd foundation by", "BSD-2-Clause-NetBSD"),
    ("this program is free software", (
        ("under the terms of the gnu general public license as published by the free software foundation, either version 3 of the license", "GPL-3.0"),
        ("under the terms of the gnu lesser general public license as published by the free software foundation, either version 3 of the license", "LGPL-3.0"),
        ("use it at your own risk; there is no warranty.", "XSkat"),)),
    ("gnu free documentation license", (
        ("version 1.1, march 2000", "GFDL-1.1"),
        ("version 1.2, november 2002", "GFDL-1.2"),
        ("version 1.3, 3 november 2008", "GFDL-1.3"))),
    ("portions of this software were developed by the unidata program at the university corporation for atmospheric research.", "NetCDF"),
    ("this file may be freely copied and redistributed as long as:", "Afmparse"),
    ("this software is provided 'as-is', without any express or implied warranty. in no event will the authors be held liable for any damages arising from the use of this software.", (
        ("source versions may not be \"relicensed\" under a different license", "Cube"),
        ("permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:", "zlib-like"),)),
    ("eiffel forum license,", (
        ("version 2", "EFL-2.0"),
        ("version 1", "EFL-1.0"))),
    ("you may copy and distribute this file freely. any queries and complaints should be forwarded to jim.davies@comlab.ox.ac.uk.", "Zed"),
    ("reciprocal public license 1.5 (rpl1.5)", "RPL-1.5"),
    ("netizen open source license", (
        ("version 1.0", "NOSL"),)),
    ("this work is being provided by the copyright holders under the following license.", "W3C-20150513"),
    ("this software is not subject to any license of the american telephone and telegraph company or of the regents of the university of california.", "Spencer-94"),
    ("open cascade technology public license", (
        ("version 6.6, april 2013", "OCCT-PL"),)),
    ("cwpuzzle.dtx is distributed in the hope that it will be useful, but without any warranty. no author or distributor accepts responsibility to anyone for the consequences of using it or for whether it serves any particular purpose or works at all, unless he says so in writing.", "Crossword"),
    ("this license agreement is between the corporation for national research initiatives, having an office at 1895 preston white drive, reston, va 20191 (\"cnri\"), and the individual or organization (\"licensee\") accessing and using jpython version 1.1.x in source or binary form and its associated documentation as provided herein (\"software\").", "CNRI-Jython"),
    ("bsd protection license", (
        ("february 2002", "BSD-Protection"),)),
    ("the open software license", (
        ("v. 1.0", "OSL-1.0"),
        ("v. 1.1", "OSL-1.1"),
        ("v. 2.1", "OSL-2.1"))),
    ("you may make and give away verbatim copies of the source", (
        ("the openldap public license", (
            ("version 1.2, 1 september 1998", "OLDAP-1.2"),
            ("version 1.1, 25 august 1998", "OLDAP-1.1"),
            ("version 1.3, 17 january 1999", "OLDAP-1.3"),
            ("version 1.4, 18 january 1999", "OLDAP-1.4"))),
        ("the net boolean public license", "NBPL-1.0"),
        ("the \"artistic license\"", "Artistic-1.0-Perl"),
        ("the artistic license", "Artistic-1.0"),
        ("the clarified artistic license", "ClArtistic"),
        ("the open group test suite license", "OGTSL"),
        ("you may make and give away verbatim copies of the source form of the software without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.", "Ruby"),
    )),
    ("gnu library general public license", (
        ("version 2.1, february 1999", "LGPL-2.1"),
        ("version 2, june 1991", "LGPL-2.0"))),
    ("gnu general public license", (
        ("version 3, 29 june 2007", "GPL-3.0"),
        ("version 1, february 1989", "GPL-1.0"),
        ("version 2, june 1991", "GPL-2.0"))),
    ("in the hope that it will be useful", (
        ("wxwindows library licence, version 3.1", "deprecated_WXwindows"),
        ("the ecos license version 2.0", "deprecated_eCos-2.0"),
    )),
    ("subject to the terms of this agreement, each contributor hereby grants", (
        ("common public license version 1.0", "CPL-1.0"),
        ("eclipse public license - v 1.0", "EPL-1.0"),
        ("lucent public license", (
            ("version 1.02", "LPL-1.02"),
            ("version 1.0", "LPL-1.0"),)),
    )),
    ("installation, use, reproduction, display, modification", (
        ("condor public license", "Condor-1.1"),
        ("eu datagrid software license", "EUDatagrid"),
    )),
    ("you are allowed to make modifications", (
        ("bittorrent open source license", (
            ("in particular, you must make the source code of your modifications available to others free of charge and without a royalty.", "BitTorrent-1.1"),
            ("in particular, you must make the source code of your modifications available to others.", "BitTorrent-1.0"))),
        ("motosoto open source license - version 0.9.1", "Motosoto"),
    )),
    ("without warranty of any kind, express or implied", (
        ("boost software license - version 1.0 - august 17th, 2003", "BSL-1.0"),
        ("licence version 2", "Eurosym"),
        ("however, if you like this product", "Giftware"),
        ("info-zip license", "Info-ZIP"),
        ("jasper license version 2.0", "JasPer-2.0"),
        ("sil open font license", (
            ("version 1.1 - 26 february 2007", "OFL-1.1"),
            ("version 1.0 - 22 november 2005", "OFL-1.0"))),
        ("the universal permissive license (upl), version 1.0", "UPL-1.0"),
        ("unicode, inc. license agreement - data files and software", (
            ("http://source.icu-project.org/repos/icu/, and http://www.unicode.org/utility/trac/browser/.", "Unicode-DFS-2016"),
            ("unicode data files do not include pdf online code charts under the directory", "Unicode-DFS-2015"))),
        ("this is free and unencumbered software released into the public domain.", "Unlicense"),
    )),
    ("you hereby grant to", (
        ("except as necessary to recognize third-party rights or third-party restriction", "OCLC-2.0"),
        ("apple public source license ver. 1.2", "APSL-1.2"),
        ("apple public source license", (
            ("version 1.1 - april 19,1999", "APSL-1.1"),
            ("version 1.0 - march 16, 1999", "APSL-1.0"),
            ("version 2.0 - august 6, 2003", "APSL-2.0"))),
        ("reciprocal public license, version 1.1", "RPL-1.1"),
        ("sybase open watcom public license version 1.0", "Watcom-1.0"),
    )),
    ("this agreement does not limit your right to distribute files", (
        ("yahoo! public license, version 1.1 (ypl)", "YPL-1.1"),
        ("yahoo! public license, version 1.0 (ypl)", "YPL-1.0"),
        ("zimbra public license, version 1.3 (zpl)", "Zimbra-1.3"),
        ("zimbra public license, version 1.4 (zpl)", "Zimbra-1.4"),
    )),
    # Snowflakes:
    ("norwegian licence for open government data (nlod)", "NLOD-1.0"),
    ("redistribution and use in any form of this material and any product thereof", "AMDPLPA"),
    ("computer associates trusted open source license", (
        ("version 1.1", "CATOSL-1.1"),)),
    ("by modifying or distributing the program", (
        ("aladdin free public license", (
            ("(version 8, november 18, 1999)", "Aladdin"),)),
    )),
    ("this program is distributed with no warranty of any sort.", "MakeIndex"),
    ("it is not allowed to remove this license", "Vim"),
    ("important: this apple software is supplied to you by apple computer, inc. (\"apple\")", "AML"),
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""This module parses licenses files or text, and give back their name, like:

>>> print(licensename.from_file('./LICENSE'))
>>> 'mit'

or as a script:

$ licensename ./LICENSE
mit

"""

import argparse
import sys
import re


from unidecode import unidecode
from licensename import __version__
from licensename.known_licenses import LICENSE_TREE


__author__ = "Julien Palard"
__copyright__ = "Julien Palard"
__license__ = "mit"


SPACES = r'(?:[ \t\f\v\u00A0\u2028])'
UNORDERED_LIST = r'(?:[*\u2022+])'
ORDERED_LIST = r'(?:[0-9]\.)'
BULLET_MARKER = r'(?:{unordered}|{ordered})'.format(
    ordered=ORDERED_LIST,
    unordered=UNORDERED_LIST)
BULLET_ITEM = r'(?:{spaces}*{bullet_marker}{spaces}+)'.format(
    bullet_marker=BULLET_MARKER,
    spaces=SPACES)


def line_match_pattern(line, patterns):
    if isinstance(patterns, str):
        return patterns
    for pattern, subpatterns in patterns:
        if pattern in line:
            found = line_match_pattern(line, subpatterns)
            if found:
                return found


def canonicalize(license_text):
    simplified_text = license_text.lower()
    # Remove leading and trailing spaces:
    simplified_text = re.sub(r'^[ \t\f\v\xa0]+|[ \xA0\u2028\r\t\f\v]+$', '',
                             simplified_text, 0, re.M)
    # Remove lists prefixes:
    simplified_text = re.sub('^[0-9*.+-]* +', '', simplified_text, 0, re.M)
    # Deduplicate spaces:
    simplified_text = re.sub(r'\s+', ' ', simplified_text, 0, re.M)
    # Replace unicode quotation marks by ascii ones
    simplified_text = unidecode(simplified_text)
    # Deduplicate double quotes (thanks Microsoft):
    simplified_text = simplified_text.replace('""', '"')
    return simplified_text


def from_lines(license_lines):
    """Parse a license text, returns a license name.
    """
    current_patterns = LICENSE_TREE
    for line in license_lines:
        if not line:
            continue
        remaining_patterns = line_match_pattern(line, current_patterns)
        if remaining_patterns:
            current_patterns = remaining_patterns
            if isinstance(current_patterns, str):
                return current_patterns


def from_text(license_text):
    """Parse a license text, returns a license name.
    """
    return from_lines(canonicalize(license_text).split('\n'))


def from_file(license_path):
    """Parse a license file, returns a license name.
    """
    with open(license_path) as license_file:
        return from_text(license_file.read().strip())


def parse_args(args):
    """Parse command line parameters

    Args:
      args ([str]): command line parameters as list of strings

    Returns:
      :obj:`argparse.Namespace`: command line parameters namespace
    """
    parser = argparse.ArgumentParser(
        description="Find name of a given license file.")
    parser.add_argument(
        '--version',
        action='version',
        version='licensename {ver}'.format(ver=__version__))
    parser.add_argument(
        '--pretty-print',
        action='store_true',
        help="Pretty print license file.")
    parser.add_argument(
        dest="license_path",
        help="Path of a license file",
        metavar="LICENSE")
    return parser.parse_args(args)


def main(args):
    """Main entry point allowing external calls

    Args:
      args ([str]): command line parameter list
    """
    args = parse_args(args)
    if args.pretty_print:
        with open(args.license_path) as license_file:
            print(canonicalize(license_file.read()))
            return
    print(from_file(args.license_path))


def run():
    """Entry point for console_scripts
    """
    main(sys.argv[1:])


if __name__ == "__main__":
    run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    Setup file for licensename.

    This file was generated with PyScaffold 2.5.7, a tool that easily
    puts up a scaffold for your new Python project. Learn more under:
    http://pyscaffold.readthedocs.org/
"""

import sys
from setuptools import setup, find_packages


with open('README.rst') as readme_file:
    readme = readme_file.read()


def setup_package():
    needs_sphinx = {'build_sphinx', 'upload_docs'}.intersection(sys.argv)
    sphinx = ['sphinx'] if needs_sphinx else []
    setup(
        name='licensename',
        version='0.4.2',
        description='Find a license name from a license file.',
        long_description=readme,
        author='Julien Palard',
        author_email='julien@palard.fr',
        license="MIT",
        url='https://github.com/JulienPalard/licensename',
        entry_points={
            'console_scripts': [
                 'licensename=licensename.licensename:run'
            ]
        },
        classifiers=[
            'Development Status :: 2 - Pre-Alpha',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            'Natural Language :: English',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6'
        ],
        setup_requires=sphinx,
        package_dir={'': 'src'},
        install_requires=['unidecode>=0.04.20'],
        packages=find_packages('src'))


if __name__ == "__main__":
    setup_package()
